@@ -1,5 +1,6 @@
 orank.default <-
-function(veg,use,rlimit,y,x.axis,y.axis,...) {
+function(veg,use,rlimit=5,y=1,x.axis=NULL,y.axis=NULL,...) {
+#  revised with new default, 25. 6. 2014
    o.orank<- orank1(veg,use,rlimit,y,x.axis,y.axis)
    class(o.orank)<- "orank"
    o.orank$call<- match.call()
